import { WatchSource } from 'vue'

export function useLoop(
  loopFunctions: (() => void | Promise<void>)[],
  interval: number | string,
  watchSources: (WatchSource | object)[] = []
) {
  let queryLoop: number | null = null
  const startQuery = async () => {
    queryLoop = 1 // 先赋值，表示已经在进行查询
    await Promise.all(loopFunctions.map(func => func()))
    queryLoop = window.setTimeout(
      startQuery,
      typeof interval === 'string'
        ? LOOP_INTERVAL[interval]
          ? LOOP_INTERVAL[interval]
          : 5 * 1000
        : interval
    )
  }
  const stopQuery = () => {
    if (queryLoop) {
      clearTimeout(queryLoop)
      queryLoop = null
    }
  }
  if (watchSources.length) {
    watch(watchSources, () => {
      stopQuery()
      startQuery()
    })
  }
  onActivated(() => {
    if (!queryLoop) {
      startQuery()
    }
  })
  onDeactivated(() => {
    stopQuery()
  })
  onBeforeUnmount(() => {
    stopQuery()
  })
}
